/**
 * 
 */
package jp.co.joyzo.office.api.base;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.ItemVersionType;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.Action;

/**
 * マイグループのIDとversionをリクエストのパラメータとして受け取り、グループの更新情報を返します。<br />
 * リクエストで受け取ったversionとOffice8が持つversionが異なる場合、レスポンスのoperationは”modify”となります。<br />
 * Office8に存在するグループをリクエストで受け取らなかった場合、レスポンスのoperationは”add”となります。<br />
 * Office8に存在しないグループをリクエストで受け取った場合、レスポンスのoperationは”remove”となります。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class BaseGetMyGroupVersions implements Action {
	
	private ItemVersionType _type = new ItemVersionType();
	
	@Override
	public String getActionName() {
		return "BaseGetMyGroupVersions";
	}

	@Override
	public APIType getAPIType() {
		return APIType.BASE;
	}
	
	/**
	 * マイグループIDとバージョン情報を追加します。<br />
	 * 
	 * @param ItemVersionType マイグループのItemVersionType
	 */
	public void addMyGroupItem(ItemVersionType type)
	{
		this._type = type;
	}
	
	
	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        for(String val: this._type.getItemList()) {
        	String[] item = val.split(",");
            OMElement facility = omFactory.createOMElement("my_group_item", null);
            facility.addAttribute("id",item[0],null);
            facility.addAttribute("version",item[1],null);
            parameters.addChild(facility);
        }
        
        return parameters;
	}
}
