/**
 * 
 */
package jp.co.joyzo.office.api.base;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.ItemVersionType;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.Action;

/**
 * ユーザーのIDとversionをリクエストのパラメータとして受け取り、ユーザーの更新情報を返します。<br />
 * リクエストで受け取ったversionとOffice8が持つversionが異なる場合、レスポンスの operation は、”modify”となります。<br />
 * Office8に存在するユーザーをリクエストで受け取らなかった場合、レスポンスの operationは、”add”となります。<br />
 * Office8に存在しないユーザーをリクエストで受け取った場合、レスポンスのoperationは、”remove”となります。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class BaseGetUserVersions implements Action {
	
	private ItemVersionType _type = new ItemVersionType();
	
	@Override
	public String getActionName() {
		return "BaseGetUserVersions";
	}

	@Override
	public APIType getAPIType() {
		return APIType.BASE;
	}
	
	/**
	 * ユーザーIDとバージョン情報を追加します。<br />
	 * 
	 * @param ItemVersionType ユーザーのItemVersionType
	 */
	public void addUserItem(ItemVersionType type)
	{
		this._type = type;
	}

	
	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        for(String val: this._type.getItemList()) {
        	String[] item = val.split(",");
            OMElement facility = omFactory.createOMElement("user_item", null);
            facility.addAttribute("id",item[0],null);
            facility.addAttribute("version",item[1],null);
            parameters.addChild(facility);
        }
        
        return parameters;
	}
}
