/**
 * 
 */
package jp.co.joyzo.office.api.base;

import java.util.ArrayList;
import java.util.List;

import jp.co.joyzo.office.api.common.APIType;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.Action;

/**
 * ユーザーIDをリクエストのパラメータとして受け取り、ユーザー情報をレスポンスとして返します。<br />
 * カスタマイズ項目の取得は行えません。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class BaseGetUsersById implements Action {
	
	private List<String> _userIds = new ArrayList<String>();
	
	@Override
	public String getActionName() {
		return "BaseGetUsersById";
	}

	@Override
	public APIType getAPIType() {
		return APIType.BASE;
	}
	
	/**
	 * ユーザーIDを追加します。
	 * 
	 * @param userid ユーザーID
	 */
	public void addUserID(String userid)
	{
		this._userIds.add( userid );
	}

	
	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        for (String id : this._userIds) {
            OMElement facility = omFactory.createOMElement("user_id", null);
            facility.setText(id);
            parameters.addChild(facility);
        }
        
        return parameters;
	}
}
