/**
 * 
 */
package jp.co.joyzo.office.api.base;

import java.util.ArrayList;
import java.util.List;

import jp.co.joyzo.office.api.common.APIType;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.Action;

/**
 * ログイン名をリクエストのパラメータとして受け取り、ユーザー情報をレスポンスとして返します。<br />
 * カスタマイズ項目の取得は行いません。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class BaseGetUsersByLoginName implements Action {
	
	private List<String> _loginNames = new ArrayList<String>();
	
	@Override
	public String getActionName() {
		return "BaseGetUsersByLoginName";
	}

	@Override
	public APIType getAPIType() {
		return APIType.BASE;
	}
	
	/**
	 * ログイン名を追加します。
	 * 
	 * @param loginname ログイン名
	 */
	public void addLoginName(String loginname)
	{
		this._loginNames.add( loginname );
	}

	
	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        for (String name : this._loginNames) {
            OMElement facility = omFactory.createOMElement("login_name", null);
            facility.setText(name);
            parameters.addChild(facility);
        }
        
        return parameters;
	}
}
