/**
 * 
 */
package jp.co.joyzo.office.api.common;


import java.util.Date;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.axiom.om.OMNamespace;

import java.text.SimpleDateFormat;


/**
 * APIとのやり取り行うSOAPのヘッダを生成するファクトリクラスです。
 * 
 * @author $api_author Office Team@Cybozu$
 * @version $api_version ver 1.0.0$
 */
public class HeaderFactory {

    /**
     * デフォルトコンストラクタ
     */
    private HeaderFactory() {
    }

    /**
     * ヘッダ内のAPIに関するノードを生成します。
     * @return org.apache.axiom.om.OMElement API情報
     */
    protected static OMElement getActionElement(String actionName) {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMNamespace actionNs = omFactory.createOMNamespace("http://schemas.xmlsoap.org/ws/2003/03/addressing", "");
        OMElement actionElement = omFactory.createOMElement("Action", actionNs);
        actionElement.addChild(omFactory.createOMText(actionElement, actionName));

        return actionElement;
    }

    /**
     * ヘッダ内のログイン情報に関するノードを生成します。
     * @return org.apache.axiom.om.OMElement ログイン情報
     */
    protected static OMElement getSecurityElement(String username, String password) {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMNamespace securityNs = omFactory.createOMNamespace("http://schemas.xmlsoap.org/ws/2002/12/secext", "");
        OMElement securityElement = omFactory.createOMElement("Security", securityNs);

        OMElement usernameTokenElement = omFactory.createOMElement("UsernameToken", securityNs);

        OMElement usernameElement = omFactory.createOMElement("Username", securityNs);
        usernameElement.addChild(omFactory.createOMText(usernameElement, username));

        OMElement passwordElement = omFactory.createOMElement("Password", securityNs);
        passwordElement.addChild(omFactory.createOMText(passwordElement, password));

        usernameTokenElement.addChild(usernameElement);
        usernameTokenElement.addChild(passwordElement);
        securityElement.addChild(usernameTokenElement);

        return securityElement;
    }

    /**
     * ヘッダ内のタイムスタンプに関するノードを生成します。
     * @return org.apache.axiom.om.OMElement タイムスタンプ情報
     */
    protected static OMElement getTimestampElement(Date createdTime, Date expiredTime) {
    	
    	SimpleDateFormat FORMATTER = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'");
    	
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMNamespace timestampNs = omFactory.createOMNamespace("http://schemas.xmlsoap.org/ws/2002/07/utility", "");
        OMElement timestampElement = omFactory.createOMElement("Timestamp", timestampNs);

        OMElement createdElement = omFactory.createOMElement("Created", timestampNs);
        createdElement.addChild(omFactory.createOMText(createdElement, FORMATTER.format(createdTime)));

        OMElement expiresElement = omFactory.createOMElement("Expires", timestampNs);
        expiresElement.addChild(omFactory.createOMText(expiresElement, FORMATTER.format(expiredTime)));

        timestampElement.addChild(createdElement);
        timestampElement.addChild(expiresElement);

        return timestampElement;
    }

}
