/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;
import jp.co.joyzo.office.api.schedule.util.FollowContentType;

/**
 * フォローを予定に追加します。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleAddFollows implements Action {

	private List<FollowContentType> _followContentTypes = new ArrayList<FollowContentType>();
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleAddFollowsのアクション名を取得します
	 * @param String "ScheduleAddFollows"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleAddFollows";
	}
	
	/**
	 * フォローの内容を追加します。
	 * @param content
	 */
	public void addFollowContent(FollowContentType content) {
		this._followContentTypes.add( content );
	}	

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for (FollowContentType type : this._followContentTypes) {
            OMElement followNode = omFactory.createOMElement("follow", null);
            followNode.addAttribute("event_id",type.getScheduleID(),null);
            followNode.addAttribute("content",type.getContent(),null);            
            parameters.addChild(followNode);
        }
        
        return parameters;
	}
}