/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;
import jp.co.joyzo.office.api.schedule.util.FollowToRepeatEventContentType;

/**
 * フォローを繰り返し予定に追加します。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleAddFollowsToRepeatEvent implements Action {

	private List<FollowToRepeatEventContentType> _followContentTypes = new ArrayList<FollowToRepeatEventContentType>();
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleAddFollowsToRepeatEventのアクション名を取得します
	 * @param String "ScheduleAddFollowsToRepeatEvent"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleAddFollowsToRepeatEvent";
	}
	
	/**
	 * フォローの内容を追加します。
	 * @param content
	 */
	public void addFollowToRepeatContent(FollowToRepeatEventContentType content) {
		this._followContentTypes.add( content );
	}	

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for (FollowToRepeatEventContentType type : this._followContentTypes) {
            OMElement followNode = omFactory.createOMElement("follow", null);
            followNode.addAttribute("event_id",type.getScheduleID(),null);
            followNode.addAttribute("content",type.getContent(),null);    
    		SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
    		followNode.addAttribute("date",formatter.format(type.getDate()),null);
    		
            parameters.addChild(followNode);
        }
        
        return parameters;
	}
}