/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.commons.lang.time.DateFormatUtils;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

import jp.co.joyzo.office.api.schedule.util.CandidateItemType;

/**
 * 仮予定を確定します。<br />
 * 確定日時はUTCで指定する必要があります。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleDetermineTemporaryEvents implements Action {

	private List<CandidateItemType> _candidateTypes = new ArrayList<CandidateItemType>();
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleDetermineTemporaryEventsのアクション名を取得します
	 * @param String "ScheduleDetermineTemporaryEvents"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleDetermineTemporaryEvents";
	}
	
	/**
	 * 仮予定の候補情報を追加します。
	 * @param type
	 */
	public void addCandidateTypes(CandidateItemType type) {
		this._candidateTypes.add( type );
	}	
	
	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        for(CandidateItemType type:this._candidateTypes){
        	OMElement candidate = omFactory.createOMElement("candidate", null);
        	candidate.addAttribute("event_id",type.getScheduleID(),null);
        	
        	String start = DateFormatUtils.ISO_DATETIME_FORMAT.format( type.getSpan().getStart() );        	
        	String end = DateFormatUtils.ISO_DATETIME_FORMAT.format( type.getSpan().getEnd() );
        	candidate.addAttribute("start",start,null);
        	candidate.addAttribute("end",end,null);
        	
        	/* facility_idを指定するとパラメーターエラーとなるので削除
        	if(type.getFacilityID() != null){
        		candidate.addAttribute("facility_id",type.getFacilityID(),null);
        	}
        	*/
        	
        	parameters.addChild(candidate);
        }
        
        return parameters;
	}
}