package jp.co.joyzo.office.api.schedule;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.commons.lang.time.DateFormatUtils;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;
import jp.co.joyzo.office.api.common.ItemVersionType;

import jp.co.joyzo.office.api.schedule.util.Span;

/**
 * 予定のIDとversion、取得期間をリクエストのパラメータとして受け取り、予定の更新情報をレスポンスとして返します。<br />
 * リクエストで受け取ったversionとOffice8が持つversionが異なる場合、レスポンスでその予定のoperationは、”modify”となります。<br />
 * リクエストで受け取らなかった予定が存在する場合、レスポンスでその予定のoperationは、”add”となります。<br />
 * 存在しない予定をリクエストで受け取った場合、レスポンスでその予定のoperationは、”remove”となります。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleGetEventVersions implements Action {
	
	private Span _span = new Span();
	private ItemVersionType _type = new ItemVersionType();
	
	@Override
	public String getActionName() {
		return "ScheduleGetEventVersions";
	}

	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}
	
	/**
	 * 検索期間を設定します。
	 * 
	 * @param span 検索期間の開始日時と終了日時
	 */
	public void setSpan(Span span)
	{
		this._span = span;
	}
	
	/**
	 * スケジュールIDとバージョン情報を追加します。<br />
	 * 
	 * @param ItemVersionType スケジュールのItemVersionType
	 */
	public void addScheduleItem(ItemVersionType type)
	{
		this._type = type;
	}

	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
    	String start = DateFormatUtils.ISO_DATETIME_FORMAT.format( this._span.getStart() );
    	String end   = DateFormatUtils.ISO_DATETIME_FORMAT.format( this._span.getEnd() );
    	
    	parameters.addAttribute("start",start,null);
    	parameters.addAttribute("end",end,null);

        for(String val: this._type.getItemList()) {
        	String[] item = val.split(",");
            OMElement facility = omFactory.createOMElement("event_item", null);
            facility.addAttribute("id",item[0],null);
            facility.addAttribute("version",item[1],null);
            parameters.addChild(facility);
        }
        
        return parameters;
	}

}
