package jp.co.joyzo.office.api.schedule;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.commons.lang.time.DateFormatUtils;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

import jp.co.joyzo.office.api.schedule.util.Span;

/**
 * 指定された日時の範囲内の予定を取得します。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleGetEvents implements Action {
	
	private Span _span = new Span();
	
	/**
	 * ScheduleGetEventsのアクション名を取得します
	 * @param String "ScheduleGetEvents"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleGetEvents";
	}

	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}
	
	/**
	 * 検索期間を設定します。
	 * 
	 * @param span 検索期間の開始日時と終了日時
	 */
	public void setSpan(Span span)
	{
		this._span = span;
	}

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
    	String start = DateFormatUtils.ISO_DATETIME_FORMAT.format( this._span.getStart() );
    	String end   = DateFormatUtils.ISO_DATETIME_FORMAT.format( this._span.getEnd() );
    	
    	parameters.addAttribute("start",start,null);
    	parameters.addAttribute("end",end,null);
        
        return parameters;
	}

}
