package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.commons.lang.time.DateFormatUtils;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

import jp.co.joyzo.office.api.schedule.util.Span;

/**
 * 指定期間内にあるユーザー、グループ、設備のいずれかの予定を検索します。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleGetEventsByTarget implements Action {
	
	private List<String> _userIds = new ArrayList<String>();
	private List<String> _groupIds = new ArrayList<String>();
	private List<String> _facilityIds = new ArrayList<String>();
	
	private Span _span = new Span();
	
	/**
	 * ScheduleGetEventsByTargetのアクション名を取得します
	 * @param String "ScheduleGetEventsByTarget"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleGetEventsByTarget";
	}

	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}
	
	/**
	 * ユーザーIDを追加します。
	 * 
	 * @param userid ユーザーID
	 */
	public void addUserID(String userid)
	{
		this._userIds.add( userid );
	}
	
	/**
	 * グループIDを追加します。
	 * 
	 * @param groupid グループID
	 */
	public void addGroupID(String groupid)
	{
		this._groupIds.add( groupid );
	}
	
	/**
	 * 施設IDを追加します。
	 * 
	 * @param facilityid 施設ID
	 */
	public void addFacilityID(String facilityid)
	{
		this._facilityIds.add( facilityid );
	}
	
	/**
	 * 検索期間を設定します。
	 * 
	 * @param span 検索期間の開始日時と終了日時
	 */
	public void setSpan(Span span)
	{
		this._span = span;
	}

	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
    	String start = DateFormatUtils.ISO_DATETIME_FORMAT.format( this._span.getStart() );
    	String end   = DateFormatUtils.ISO_DATETIME_FORMAT.format( this._span.getEnd() );
    	
    	parameters.addAttribute("start",start,null);
    	parameters.addAttribute("end",end,null);

        for (String id : this._userIds) {	//ユーザーIDをセット
            OMElement user = omFactory.createOMElement("user", null);
            user.addAttribute("id",id,null);
            parameters.addChild(user);
        }

        for (String id : this._groupIds) {	//グループIDをセット
            OMElement group = omFactory.createOMElement("group", null);
            group.addAttribute("id",id,null);
            parameters.addChild(group);
        }
        
        for (String id : this._facilityIds) {	//施設IDをセット
            OMElement facility = omFactory.createOMElement("facility", null);
            facility.addAttribute("id",id,null);
            parameters.addChild(facility);
        }
        
        return parameters;
	}

}
