package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;


/**
 * 設備IDを元に設備の詳細情報を取得します。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleGetFacilitiesById implements Action {
	
	private List<String> _facilityIds = new ArrayList<String>();
	
	/**
	 * ScheduleGetFacilitiesByIdのアクション名を取得します
	 * @param String "ScheduleGetFacilitiesById"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleGetFacilitiesById";
	}

	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}
	
	/**
	 * 設備IDを追加します。
	 * 
	 * @param scheduleid 設備ID
	 */
	public void addFacilityID(String facilityid)
	{
		this._facilityIds.add( facilityid );
	}

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for (String id : this._facilityIds) {	//予定IDをセット
            OMElement facility = omFactory.createOMElement("facility_id", null);
            facility.setText(id);
            parameters.addChild(facility);
        }
        
        return parameters;
	}

}
