package jp.co.joyzo.office.api.schedule;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;
import jp.co.joyzo.office.api.common.ItemVersionType;


/**
 * 設備グループの更新情報を取得します。<br />
 * Office8がリクエストで受け取ったversionとOffice8が持つversionが異なる場合、レスポンスでその設備グループのoperationは、”modify”となります。<br />
 * リクエストで受け取らなかった予定が存在する場合、レスポンスでその設備グループのoperationは、”add”となります。<br />
 * 存在しない予定をリクエストで受け取った場合、レスポンスでその設備グループのoperationは、”remove”となります。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleGetFacilityGroupsVersions implements Action {
	
	private ItemVersionType _type = new ItemVersionType();
	
	/**
	 * ScheduleGetFacilityGroupsVersionsのアクション名を取得します
	 * @param String "ScheduleGetFacilityGroupsVersions"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleGetFacilityGroupsVersions";
	}

	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}
	
	/**
	 * 設備IDとバージョン情報を追加します。<br />
	 * 
	 * @param ItemVersionType 設備のItemVersionType
	 */
	public void addFacilityGroupItem(ItemVersionType type)
	{
		this._type = type;
	}

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
    	for(String val: this._type.getItemList()) {
        	String[] item = val.split(",");
            OMElement facility = omFactory.createOMElement("facility_group_item", null);
            facility.addAttribute("id",item[0],null);
            facility.addAttribute("version",item[1],null);
            parameters.addChild(facility);
        }
        
        
        return parameters;
	}

}
