package jp.co.joyzo.office.api.schedule;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;


/**
 * スケジュールアプリに関する設定を取得します。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleGetProfiles implements Action {
	
	private boolean _systemProfile = false;
	
	/**
	 * ScheduleGetProfilesのアクション名を取得します
	 * @param String "ScheduleGetProfiles"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleGetProfiles";
	}

	/**
	 * スケジュールAPIのAPITypeを取得します。（初期値はfalse）
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}
	
	/**
	 * システム設定の取得可否を設定します。
	 * 
	 * @param systemProfile システム設定の取得可否
	 */
	public void setSystemProfile(boolean systemProfile)
	{
		this._systemProfile = systemProfile;
	}

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        if(this._systemProfile)
        	parameters.addAttribute("include_system_profile","true",null);
        else
        	parameters.addAttribute("include_system_profile","false",null);        	
        
        return parameters;
	}

}
