package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;


/**
 * API実行ユーザーが参加している予定から抜けます。<br />
 * 繰り返し予定と仮予定からは抜けることはできません。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleLeaveEvents implements Action {
	
	private List<String> _scheduleIds = new ArrayList<String>();
	
	/**
	 * ScheduleLeaveEventsのアクション名を取得します
	 * @param String "ScheduleLeaveEvents"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleLeaveEvents";
	}

	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}
	
	/**
	 * 抜ける予定IDを追加します。
	 * 
	 * @param scheduleid 予定ID
	 */
	public void addScheduleID(String scheduleid)
	{
		this._scheduleIds.add( scheduleid );
	}

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for (String id : this._scheduleIds) {	//予定IDをセット
            OMElement facility = omFactory.createOMElement("event_id", null);
            facility.setText(id);
            parameters.addChild(facility);
        }
        
        return parameters;
	}

}
