/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMElement;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

import jp.co.joyzo.office.api.schedule.util.ModifyRepeatEventsOperationType;
import jp.co.joyzo.office.api.schedule.util.ScheduleUtil;

/**
 * 登録されている繰り返し予定を変更します。<br />
 * 入力した予定IDを元に予定を特定し変更します。<br />
 * 入力した情報をその予定に更新し、入力しないところも空の値として更新します。<br />
 * 予定のフォローは入力しても更新されません。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleModifyRepeatEvents implements Action {

	private List<ModifyRepeatEventsOperationType> _events = new ArrayList<ModifyRepeatEventsOperationType>();
	
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleModifyRepeatEventsのアクション名を取得します
	 * @param String "ScheduleModifyRepeatEvents"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleModifyRepeatEvents";
	}
	
	/**
	 * 変更する繰り返し予定を設定します。
	 * @param event
	 */
	public void addModifyRepeatEvent( ModifyRepeatEventsOperationType event ) {
		this._events.add( event );
	}	

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
		return ScheduleUtil.toParameterForModifyRepeatEvents(this._events);
	}
}