/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

import jp.co.joyzo.office.api.schedule.util.ParticipateEventsToRepeatEventOperationType;

/**
 * 登録されている繰り返し予定に参加します。<br />
 * 特定の日時のみに参加と、特定の日時以降のみ参加の処理を行った場合、通常のOffice上の操作と同じように<br />
 * 元の繰り返し予定から分離した予定として扱われます。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleParticipateEventsToRepeatEvent implements Action {

	private List<ParticipateEventsToRepeatEventOperationType> _operationTypes = new ArrayList<ParticipateEventsToRepeatEventOperationType>();
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleParticipateEventsToRepeatEventのアクション名を取得します
	 * @param String "ScheduleParticipateEventsToRepeatEvent"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleParticipateEventsToRepeatEvent";
	}
	
	/**
	 * 参加する繰り返し予定情報を追加します。
	 * @param type
	 */
	public void addEventOperationType(ParticipateEventsToRepeatEventOperationType type) {
		this._operationTypes.add( type );
	}	

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        for(ParticipateEventsToRepeatEventOperationType type:this._operationTypes){
        	OMElement operation = omFactory.createOMElement("operation", null);
        	operation.addAttribute("event_id",type.getScheduleID(),null);
        	operation.addAttribute("type",type.getRepeatModifyType().toString().toLowerCase(),null);
        	
        	if(type.getDate() != null){
        		SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
            	operation.addAttribute("date",formatter.format(type.getDate()),null);        		
        	}
        	
        	parameters.addChild(operation);

        }
        
        return parameters;
	}
}