/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

/**
 * 登録されている予定を削除します。<br />
 * 入力した予定IDを元に予定を特定し削除します。<br />
 * 削除が成功した場合、空のSOAPメッセージを返します。<br />
 * 入力した予定IDの中に一つでも存在しない予定IDが含まれている場合は削除処理が行われず、エラーメッセージ（501）が返されます。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleRemoveEvents implements Action {

	private List<String> _scheduleIds = new ArrayList<String>();
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleRemoveEventsのアクション名を取得します
	 * @param String "ScheduleRemoveEvents"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleRemoveEvents";
	}
	
	/**
	 * 削除する予定IDを追加します。
	 * @param scheduleid
	 */
	public void addScheduleID(String scheduleid) {
		this._scheduleIds.add( scheduleid );
	}	

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for (String id : this._scheduleIds) {	//予定IDをセット
            OMElement facility = omFactory.createOMElement("event_id", null);
            facility.setText(id);
            parameters.addChild(facility);
        }
        
        return parameters;
	}
}