/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

import jp.co.joyzo.office.api.schedule.util.RemoveEventsFromRepeatEventOperationType;

/**
 * 登録されている繰り返し予定を削除します。<br />
 * 入力した予定IDと削除範囲を元に予定を特定し削除します。<br />
 * 削除した繰り返し予定の情報をレスポンスとして返します。<br />
 * 入力した予定IDの中に一つでも存在しない予定IDが含まれている場合は削除処理が行われず、エラーメッセージ（501）が返されます。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleRemoveEventsFromRepeatEvent implements Action {

	private List<RemoveEventsFromRepeatEventOperationType> _operationTypes = new ArrayList<RemoveEventsFromRepeatEventOperationType>();
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleRemoveEventsFromRepeatEventのアクション名を取得します
	 * @param String "ScheduleRemoveEventsFromRepeatEvent"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleRemoveEventsFromRepeatEvent";
	}
	
	/**
	 * 削除する繰り返し予定情報を追加します。
	 * @param type
	 */
	public void addEventOperationType(RemoveEventsFromRepeatEventOperationType type) {
		this._operationTypes.add( type );
	}	

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        for(RemoveEventsFromRepeatEventOperationType type:this._operationTypes){
        	OMElement operation = omFactory.createOMElement("operation", null);
        	operation.addAttribute("event_id",type.getScheduleID(),null);
        	operation.addAttribute("type",type.getRepeatModifyType().toString().toLowerCase(),null);
        	
        	if(type.getDate() != null){
        		SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
            	operation.addAttribute("date",formatter.format(type.getDate()),null);        		
        	}
        	
        	parameters.addChild(operation);

        }
        
        return parameters;
	}
}