/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

/**
 * 登録されているフォローを削除します。<br />
 * 入力したフォローIDを元にフォローを特定し削除します。<br />
 * 削除が成功した場合、空のSOAPメッセージを返します。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleRemoveFollows implements Action {

	private List<String> _followIds = new ArrayList<String>();
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleRemoveFollowsのアクション名を取得します
	 * @param String "ScheduleRemoveFollows"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleRemoveFollows";
	}
	
	/**
	 * 削除するフォローIDを追加します。
	 * @param followid
	 */
	public void addFollowID(String followid) {
		this._followIds.add( followid );
	}	

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);

        for (String id : this._followIds) {	//予定IDをセット
            OMElement facility = omFactory.createOMElement("follow_id", null);
            facility.setText(id);
            parameters.addChild(facility);
        }
        
        return parameters;
	}
}