/**
 * 
 */
package jp.co.joyzo.office.api.schedule;

import java.util.ArrayList;
import java.util.List;

import org.apache.axiom.om.OMAbstractFactory;
import org.apache.axiom.om.OMElement;
import org.apache.axiom.om.OMFactory;
import org.apache.commons.lang.time.DateFormatUtils;

import jp.co.joyzo.office.api.common.APIType;
import jp.co.joyzo.office.api.common.Action;

import jp.co.joyzo.office.api.schedule.util.Member;
import jp.co.joyzo.office.api.schedule.util.SearchConditionType;
import jp.co.joyzo.office.api.schedule.util.SearchFreeTimesCandidateType;
/**
 * 検索条件を元に空き時間を検索します。
 * 
 * @author joyzo Corp,Inc.
 * @version $api_version ver 2.0.0$
 */
public class ScheduleSearchFreeTimes implements Action {

	private List<Member> _members = new ArrayList<Member>();
	private List<SearchFreeTimesCandidateType> _candidateTypes = new ArrayList<SearchFreeTimesCandidateType>();
	private SearchConditionType _conditionType;
	private String _searchTime = null;
	
	/**
	 * スケジュールAPIのAPITypeを取得します
	 * @param APIType スケジュールAPIType
	 */
	@Override
	public APIType getAPIType() {
		return APIType.SCHEDULE;
	}

	/**
	 * ScheduleSearchFreeTimesのアクション名を取得します
	 * @param String "ScheduleSearchFreeTimes"のアクション名
	 */
	@Override
	public String getActionName() {
		return "ScheduleSearchFreeTimes";
	}
	
	/**
	 * 参加者を追加します。
	 * @param member
	 */
	public void addMember(Member member) {
		this._members.add( member );
	}	
	
	/**
	 * 検索の時間候補の範囲を追加します。
	 * @param type
	 */
	public void addCandidateType(SearchFreeTimesCandidateType type) {
		this._candidateTypes.add( type );
	}	
	
	/**
	 * 設備の条件を設定します。
	 * 
	 * @param type 設備の条件
	 */
	public void setConditionType(SearchConditionType type)
	{
		this._conditionType = type;
	}
	
	/**
	 * 所要時間を設定します。
	 * 
	 * @param type 所要時間の条件
	 */
	public void setSearchTime(String time)
	{
		this._searchTime = time;
	}

	/**
	 * parametersタグを生成します。
	 * 
	 * @return OMElement 生成されたparametersタグ
	 */
	@Override
	public OMElement getParameters() {
        OMFactory omFactory = OMAbstractFactory.getOMFactory();
        OMElement parameters = omFactory.createOMElement("parameters", null);
        
        parameters.addAttribute("search_time", this._searchTime, null);
        parameters.addAttribute("search_condition",this._conditionType.toString().toLowerCase(),null);
        
        for(SearchFreeTimesCandidateType condidateType:this._candidateTypes){
        	OMElement candidate = omFactory.createOMElement("candidate", null);
        	String start = DateFormatUtils.ISO_DATETIME_FORMAT.format( condidateType.getSpan().getStart() );        	
        	String end = DateFormatUtils.ISO_DATETIME_FORMAT.format( condidateType.getSpan().getEnd() );
        	
        	candidate.addAttribute("start",start,null);
        	candidate.addAttribute("end",end,null);
        	
        	parameters.addChild(candidate);
        }

    	for( Member member : this._members )
    	{
    		OMElement memberNode = omFactory.createOMElement("member", null);
    		OMElement idNode = omFactory.createOMElement(member.getType().toString().toLowerCase(), null);
    		idNode.addAttribute("id", String.valueOf(member.getID()), null);
    		idNode.addAttribute("order", String.valueOf(member.getOrder()), null);
    		memberNode.addChild( idNode );
    		parameters.addChild( memberNode );
    	}
        
        return parameters;
	}
}